import {
  EditKlinkDetails,
  KlinkDetails,
  KlinkList,
  ViewKlinkDetails,
} from '../../common/types'
import log from 'electron-log'
import { createClient } from './api-client'

const client = createClient()

export async function createKlink(klinkDetails: KlinkDetails) {
  log.info('[Klink] Creating klink')
  console.log(klinkDetails)

  try {
    const result = await client.post('/frontvault/v1/tokens', klinkDetails)
    const { data } = result
    return data
  } catch (e) {
    log.error(`[Klink] Unable to create Klink: ${e.message}`)
    throw new Error(e.message)
  }
}

export async function getCurrentUserKlinks(page?: number): Promise<KlinkList> {
  log.info('[Klink] Reading current user klinks')

  try {
    const response = await client.get(`/frontvault/v1/tokens?page=${page}`)
    return response.data
  } catch (e) {
    log.error(`[Klink] Unable to read Klinks: ${e.message}`)

    throw new Error('Unable to access Klink storage')
  }
}

export async function readKlink(
  klinkToken: string
): Promise<ViewKlinkDetails | EditKlinkDetails> {
  log.info('[Klink] Reading klink')

  try {
    const { data } = await client.get(`/frontvault/v1/tokens/${klinkToken}`)
    console.log(data)
    const { token, title, sharedWith, notifications, url } = data

    if (!data.is_read_only) {
      return {
        editable: true,
        token,
        title,
        sharedWith,
        notifications,
        data: data.data,
        url,
      }
    }

    return {
      editable: false,
      token,
      title,
      data: data.data,
      url: url,
    }
  } catch (e) {
    if (e.response && e.response.status === 500) {
      throw new Error('Klink not found')
    }

    log.error(`[Klink] Unable to read Klink: ${e.message}`)

    throw new Error('Unable to access Klink storage')
  }
}

export async function editKlink(
  token: string,
  klinkDetails: KlinkDetails
): Promise<void> {
  log.info('[Klink] Modifying klink')

  const { title, body, sharedWith, notifications } = klinkDetails

  const requestBody = {
    title,
    body,
    sharedWith,
    token,
    notifications,
  }

  try {
    console.log(requestBody)
    await client.put('/frontvault/v1/tokens', requestBody)
  } catch (e) {
    if (e.response && e.response.status === 403) {
      throw new Error('No access to modify this klink, try logging in again')
    }

    log.error(`[Klink] Unable to modify Klink: ${e.message}`)

    throw new Error('Unable to access Klink storage')
  }
}
