import db from '../Database'
import { Contact } from '../../types'

export const findContactsByPhone = (phone: string): Promise<Contact[]> => {
  return db.contacts.filter((contact) => contact.phone.includes(phone)).toArray()
}

export const getContactsWithPhones = async (phones: string[]): Promise<Contact[]> => {
  await Promise.all(
    phones.map(async (phone) => {
      return db.transaction('rw', db.contacts, async () => {
        const foundContact = await db.contacts.get({ phone })

        if (!foundContact) {
          db.contacts.add({ name: '', phone })
        }
      })
    })
  )

  return db.contacts.filter((contact) => phones.includes(contact.phone)).toArray()
}

export const findContactsByName = (name: string): Promise<Contact[]> => {
  return db.contacts.filter((contact) => contact.name.includes(name)).toArray()
}

export const saveContacts = (contacts: Contact[]): Promise<void> => {
  try {
    return db.transaction('rw', db.contacts, async () => {
      for await (let contact of contacts) {
        const foundContact = await db.contacts.get({ phone: contact.phone })

        if (foundContact) {
          await db.contacts.update(foundContact.id!, contact)
        } else {
          await db.contacts.add(contact)
        }
      }
    })
  } catch (e) {
    throw new Error('Contacts not saved')
  }
}

export const getContacts = () => db.contacts.toArray()
