import React, { useState } from 'react'
import { KlinkDetails } from '../../../common/types'
import { KlinkDetailsWithContacts } from '../../types'
import { getKlinkDetails } from '../../utils'
import KlinkDetailsForm from '../KlinkDetailsForm'
import { saveContacts } from '../ContactsRepository'
import ActionButtons from '../ActionButtons'

type Props = {
  defaultData: string
  createKlink: (klinkRequest: KlinkDetails) => Promise<void>
  close: () => void
}

const CreateKlinkDialog = ({ defaultData, createKlink, close }: Props) => {
  const [details, setDetails] = useState<KlinkDetailsWithContacts>({
    title: '',
    body: defaultData,
    sharedWith: [],
    notifications: false,
  })
  const { title, body, sharedWith, notifications } = details

  const [loading, setLoading] = useState(false)
  const [error, setError] = useState<string | null>(null)

  const createKlinkAction = async () => {
    try {
      setLoading(true)
      await saveContacts(details.sharedWith)
      await createKlink(getKlinkDetails(details))
    } catch (e) {
      setError(e)
      setLoading(false)
    }
  }

  return (
    <div>
      {error && <div>Error: {error}</div>}
      <KlinkDetailsForm
        title={title}
        body={body}
        sharedWith={sharedWith}
        notifications={notifications}
        onChange={(details) => {
          setDetails(details)
          setError(null)
        }}
      />
      <ActionButtons
        loading={loading}
        actionName={loading ? 'Loading...' : 'Create'}
        action={createKlinkAction}
        close={close}
      />
    </div>
  )
}

export default CreateKlinkDialog
