import React, { useEffect, useState } from 'react'
import CircularProgress from '@material-ui/core/CircularProgress';
import { EditKlinkDetails, KlinkList } from '../../../common/types'
import { TablePagination } from './TablePagination'
import { KlinkTable } from './KlinksTable'

type Props = {
  getKlinks(page: number): Promise<KlinkList>,
}

const Klinks = ({ getKlinks }: Props) => {
  const [page, setPage] = useState(1)
  const [totalPages, setTotalPages] = useState<number>()
  const [klinks, setKlinks] = useState<EditKlinkDetails[]>([])
  const [loading, setLoading] = useState(false)

  useEffect(() => {
    setLoading(true)
    getKlinks(page)
      .then((klinkList) => {
        setTotalPages(klinkList.max_page)
        setKlinks(klinkList.tokens)
      })
      .finally(() => setLoading(false))
  }, [getKlinks, page])

  return (
    <>
      <h3>My Klinks</h3>
      {loading && <CircularProgress />}
      {!loading && !klinks.length && <span>No klinks created. Created klinks will be shown here</span>}
      <KlinkTable klinks={klinks} />
      <TablePagination currentPage={page} onChange={setPage} totalPages={totalPages || 1} />
    </>
  )
}

export default Klinks
